.. Quenbee documentation master file, created by
   sphinx-quickstart on Wed Mar 13 20:09:41 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Queenbee
========

Welcome to Queenbee's Documention site! 


.. toctree::
   :maxdepth: 1

   README.md
   guides/index
   schemas/index
   cli/index
   modules
